SVN: security/cve_reader.py

shadzik shadzik at pld-linux.org
Fri May 23 01:23:02 CEST 2008


Author: shadzik
Date: Fri May 23 01:23:02 2008
New Revision: 9762

Modified:
   security/cve_reader.py
Log:
- hopefully fix an ugly bug where deleted patches with CVE reference kode in their name where treated like proper CVE entries


Modified: security/cve_reader.py
==============================================================================
--- security/cve_reader.py	(original)
+++ security/cve_reader.py	Fri May 23 01:23:02 2008
@@ -106,8 +106,8 @@
 						if mem == "":
 							foundrange = 0
 					else:
-						# Check if in added line exists some CVE note
-						if re.match('^\+.*(CVE-[0-9\-]+)', lines[i+cvslog]):
+						# Check if in added line exists some CVE note and it's not a patch that was removed
+						if re.match('^\+.*(CVE-[0-9\-]+)', lines[i+cvslog]) and re.match('!.*(\.patch).*', lines[i+cvslog]) and re.match('!.*(\.diff).*', lines[cvslog]):
 							if foundrange == 1:
 								foundcveafterrange = 1
 							


More information about the pld-cvs-commit mailing list